
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_n_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.190957'}

wordnet_terms_n = [
    'na',
    'naan',
    'nab',
    'nabalus',
    'nabbed',
    'nablus',
    'nabob',
    'nabokov',
    'naboom',
    'nabothian',
    'nabu',
    'nabumetone',
    'nac',
    'nacelle',
    'nacho',
    'nacimiento',
    'nacre',
    'nacreous',
    'nad',
    'nada',
    'nadine',
    'nadir',
    'nadolol',
    'nadp',
    'nadu',
    'naemorhedus',
    'nafcil',
    'nafcillin',
    'nafta',
    'nafud',
    'nag',
    'naga',
    'nagami',
    'nagano',
    'nagari',
    'nagasaki',
    'nageia',
    'nagged',
    'nagger',
    'nagging',
    'nagi',
    'nagoya',
    'nags',
    'nahuatl',
    'nahum',
    'naiad',
    'naiadaceae',
    'naiadales',
    'naiant',
    'naias',
    'naif',
    'naiki',
    'nail',
    'nailbrush',
    'nailed',
    'nailer',
    'nailfile',
    'nailhead',
    'nailing',
    'nailrod',
    'nails',
    'nainsook',
    'naira',
    'nairobi',
    'naismith',
    'naive',
    'naively',
    'naiveness',
    'naivete',
    'naivety',
    'naja',
    'najadaceae',
    'najas',
    'najd',
    'naked',
    'nakedness',
    'nakedwood',
    'nakuru',
    'nalchik',
    'nalfon',
    'nalline',
    'nalorphine',
    'naloxone',
    'naltrexone',
    'nam',
    'name',
    'named',
    'namedrop',
    'nameko',
    'nameless',
    'namelessness',
    'nameplate',
    'namer',
    'names',
    'namesake',
    'namibia',
    'namibian',
    'naming',
    'nammad',
    'nammu',
    'namoi',
    'nampa',
    'namtar',
    'namtaru',
    'namur',
    'nan',
    'nanaimo',
    'nanak',
    'nance',
    'nancere',
    'nanchang',
    'nancy',
    'nandrolone',
    'nandu',
    'nanism',
    'nanjing',
    'nankeen',
    'nanking',
    'nanna',
    'nanning',
    'nanny',
    'nanocephalic',
    'nanocephaly',
    'nanogram',
    'nanometer',
    'nanometers',
    'nanometre',
    'nanomia',
    'nanophthalmos',
    'nanosecond',
    'nanotechnology',
    'nanotube',
    'nanovolt',
    'nansen',
    'nantes',
    'nanticoke',
    'nantua',
    'nantucket',
    'nanus',
    'naomi',
    'nap',
    'napa',
    'napaea',
    'napalm',
    'nape',
    'napery',
    'naphazoline',
    'naphtha',
    'naphthalene',
    'naphthol',
    'naphthoquinone',
    'napier',
    'napkin',
    'napkins',
    'naples',
    'napoleon',
    'napoleonic',
    'napoli',
    'napped',
    'napping',
    'nappy',
    'naprapath',
    'naprapathy',
    'naprosyn',
    'naproxen',
    'naps',
    'napu',
    'naqua',
    'nara',
    'naranjilla',
    'narc',
    'narcan',
    'narcism',
    'narcissism',
    'narcissist',
    'narcissistic',
    'narcissus',
    'narcist',
    'narcolepsy',
    'narcoleptic',
    'narcosis',
    'narcoterrorism',
    'narcotic',
    'narcotics',
    'narcotise',
    'narcotised',
    'narcotising',
    'narcotize',
    'narcotized',
    'narcotizing',
    'narcotraffic',
    'nard',
    'nardil',
    'nardo',
    'nardoo',
    'nares',
    'narghile',
    'nargileh',
    'narial',
    'naris',
    'nark',
    'narragansett',
    'narrate',
    'narrates',
    'narrating',
    'narration',
    'narrative',
    'narrator',
    'narrow',
    'narrowboat',
    'narrowed',
    'narrower',
    'narrowest',
    'narrowing',
    'narrowly',
    'narrowness',
    'narrows',
    'narthecium',
    'narthex',
    'narwal',
    'narwhal',
    'narwhale',
    'narwhals',
    'nary',
    'nasa',
    'nasal',
    'nasale',
    'nasalis',
    'nasalisation',
    'nasalise',
    'nasality',
    'nasalization',
    'nasalize',
    'nasalizes',
    'nasally',
    'nascence',
    'nascency',
    'nascent',
    'nasdaq',
    'naseby',
    'nash',
    'nashville',
    'nasion',
    'nasopharyngeal',
    'nasopharynx',
    'nassau',
    'nasser',
    'nast',
    'nastiness',
    'nasturtium',
    'nasty',
    'nasua',
    'natal',
    'natality',
    'natantia',
    'natation',
    'natator',
    'natatorium',
    'natchez',
    'nates',
    'nathaniel',
    'naticidae',
    'nation',
    'national',
    'nationalisation',
    'nationalise',
    'nationalism',
    'nationalist',
    'nationalistic',
    'nationalists',
    'nationality',
    'nationalization',
    'nationalize',
    'nationalized',
    'nationally',
    'nationals',
    'nationhood',
    'nations',
    'nationwide',
    'native',
    'nativeness',
    'natives',
    'nativism',
    'nativist',
    'nativistic',
    'nativity',
    'nato',
    'natriuresis',
    'natriuretic',
    'natrix',
    'natrolite',
    'natta',
    'natter',
    'natterjack',
    'nattiness',
    'natty',
    'natural',
    'naturalisation',
    'naturalise',
    'naturalised',
    'naturalism',
    'naturalist',
    'naturalistic',
    'naturalization',
    'naturalize',
    'naturalized',
    'naturally',
    'naturalness',
    'nature',
    'natures',
    'naturism',
    'naturist',
    'naturistic',
    'naturopath',
    'naturopathy',
    'nauch',
    'nauclea',
    'naucrates',
    'naught',
    'naughtily',
    'naughtiness',
    'naughty',
    'naumachia',
    'naumachy',
    'naupathia',
    'nauru',
    'nauruan',
    'nausea',
    'nauseant',
    'nauseate',
    'nauseated',
    'nauseating',
    'nauseatingness',
    'nauseous',
    'nautch',
    'nautical',
    'nautilidae',
    'nautilus',
    'navaho',
    'navajo',
    'navajos',
    'naval',
    'navane',
    'navarino',
    'nave',
    'navel',
    'navicular',
    'navigability',
    'navigable',
    'navigate',
    'navigated',
    'navigating',
    'navigation',
    'navigational',
    'navigator',
    'navigators',
    'navratilova',
    'navvy',
    'navy',
    'nawab',
    'nawcwpns',
    'nay',
    'nays',
    'naysayer',
    'naysaying',
    'nazarene',
    'nazarenes',
    'nazareth',
    'naze',
    'nazi',
    'nazification',
    'nazified',
    'nazify',
    'naziism',
    'nazimova',
    'nazis',
    'nazism',
    'nb',
    'nbe',
    'nbw',
    'nc',
    'ncaa',
    'ncdc',
    'nd',
    'ndebele',
    'ndjamena',
    'ne',
    'neandertal',
    'neanderthal',
    'neanderthalian',
    'neap',
    'neapolitan',
    'near',
    'nearby',
    'neared',
    'nearer',
    'nearest',
    'nearly',
    'nearness',
    'nears',
    'nearside',
    'nearsighted',
    'nearsightedness',
    'neat',
    'neaten',
    'neatly',
    'neatness',
    'neb',
    'nebbech',
    'nebbish',
    'nebcin',
    'nebe',
    'nebiim',
    'nebn',
    'nebo',
    'nebraska',
    'nebraskan',
    'nebuchadnezzar',
    'nebuchadrezzar',
    'nebula',
    'nebulae',
    'nebular',
    'nebule',
    'nebuliser',
    'nebulizer',
    'nebulose',
    'nebulous',
    'nec',
    'necessarily',
    'necessary',
    'necessitarian',
    'necessitate',
    'necessitated',
    'necessitating',
    'necessities',
    'necessitous',
    'necessity',
    'neck',
    'neckar',
    'neckband',
    'neckcloth',
    'necked',
    'necker',
    'neckerchief',
    'necking',
    'necklace',
    'neckless',
    'necklet',
    'necklike',
    'neckline',
    'neckpiece',
    'necks',
    'necktie',
    'neckwear',
    'necrobiosis',
    'necrology',
    'necrolysis',
    'necromancer',
    'necromancy',
    'necromania',
    'necromantic',
    'necromantical',
    'necrophagia',
    'necrophagy',
    'necrophilia',
    'necrophilism',
    'necropolis',
    'necropsy',
    'necrose',
    'necrosis',
    'necrotic',
    'nectar',
    'nectaries',
    'nectariferous',
    'nectarine',
    'nectarous',
    'nectary',
    'necturus',
    'nederland',
    'nee',
    'need',
    'needed',
    'needer',
    'needful',
    'neediest',
    'neediness',
    'needing',
    'needle',
    'needlebush',
    'needlecraft',
    'needled',
    'needlefish',
    'needlelike',
    'needlepoint',
    'needles',
    'needless',
    'needlessly',
    'needlewoman',
    'needlewood',
    'needlework',
    'needleworker',
    'needs',
    'needy',
    'neel',
    'neem',
    'neencephalon',
    'nefarious',
    'nefariousness',
    'nefazodone',
    'nefertiti',
    'nefud',
    'negaprion',
    'negate',
    'negating',
    'negation',
    'negations',
    'negative',
    'negatively',
    'negativeness',
    'negatives',
    'negativism',
    'negativist',
    'negativity',
    'negatron',
    'negev',
    'neggram',
    'neglect',
    'neglected',
    'neglecter',
    'neglectful',
    'neglectfulness',
    'neglecting',
    'neglects',
    'neglige',
    'negligee',
    'negligence',
    'negligent',
    'negligently',
    'negligible',
    'negociate',
    'negociated',
    'negotiable',
    'negotiant',
    'negotiate',
    'negotiated',
    'negotiates',
    'negotiating',
    'negotiation',
    'negotiations',
    'negotiator',
    'negotiatress',
    'negotiatrix',
    'negritude',
    'negro',
    'negroes',
    'negroid',
    'negus',
    'nehemiah',
    'nehru',
    'neigh',
    'neighbor',
    'neighborhood',
    'neighboring',
    'neighborliness',
    'neighborly',
    'neighbors',
    'neighbour',
    'neighbourhood',
    'neighbourliness',
    'neighbourly',
    'neighing',
    'neisseria',
    'neither',
    'nejd',
    'nekton',
    'nelfinavir',
    'nelson',
    'nelumbo',
    'nelumbonaceae',
    'nematocera',
    'nematoda',
    'nematode',
    'nematodes',
    'nembutal',
    'nemea',
    'nemean',
    'nemertea',
    'nemertean',
    'nemertina',
    'nemertine',
    'nemesis',
    'nemophila',
    'nenets',
    'nentsi',
    'nentsy',
    'neo',
    'neobiotic',
    'neoceratodus',
    'neoclassic',
    'neoclassical',
    'neoclassicism',
    'neoclassicist',
    'neoclassicistic',
    'neocolonialism',
    'neocon',
    'neoconservatism',
    'neoconservative',
    'neocortex',
    'neocortical',
    'neodymium',
    'neoencephalon',
    'neoexpressionism',
    'neofiber',
    'neohygrophorus',
    'neolentinus',
    'neoliberal',
    'neoliberalism',
    'neolith',
    'neolithic',
    'neologism',
    'neologist',
    'neology',
    'neomycin',
    'neomys',
    'neon',
    'neonatal',
    'neonate',
    'neonates',
    'neonatology',
    'neopallium',
    'neophobia',
    'neophron',
    'neophyte',
    'neoplasia',
    'neoplasm',
    'neoplasms',
    'neoplastic',
    'neoplatonism',
    'neoplatonist',
    'neopolitan',
    'neoprene',
    'neoromanticism',
    'neosho',
    'neosporin',
    'neostigmine',
    'neotenic',
    'neotenous',
    'neoteny',
    'neotoma',
    'neotony',
    'nepa',
    'nepal',
    'nepalese',
    'nepali',
    'nepenthaceae',
    'nepenthes',
    'nepeta',
    'nepheline',
    'nephelinite',
    'nephelite',
    'nephelium',
    'nephew',
    'nephology',
    'nephoscope',
    'nephralgia',
    'nephrectomy',
    'nephrite',
    'nephritic',
    'nephritis',
    'nephroangiosclerosis',
    'nephroblastoma',
    'nephrocalcinosis',
    'nephrolepis',
    'nephrolith',
    'nephrolithiasis',
    'nephrology',
    'nephron',
    'nephropathy',
    'nephrops',
    'nephropsidae',
    'nephroptosia',
    'nephroptosis',
    'nephrosclerosis',
    'nephrosis',
    'nephrotomy',
    'nephrotoxic',
    'nephrotoxin',
    'nephthys',
    'nephthytis',
    'nepidae',
    'nepotism',
    'nepotist',
    'neptune',
    'neptunium',
    'nerd',
    'nereid',
    'nereids',
    'nereus',
    'nergal',
    'nerita',
    'neritic',
    'neritid',
    'neritidae',
    'neritids',
    'neritina',
    'nerium',
    'nernst',
    'nero',
    'nerodia',
    'nerthus',
    'neruda',
    'nerva',
    'nerve',
    'nerveless',
    'nervelessness',
    'nerveroot',
    'nerves',
    'nervi',
    'nervosa',
    'nervous',
    'nervously',
    'nervousness',
    'nervure',
    'nervus',
    'nervy',
    'nescience',
    'nescient',
    'nesokia',
    'ness',
    'nesselrode',
    'nessie',
    'nest',
    'nester',
    'nesting',
    'nestle',
    'nestled',
    'nestles',
    'nestling',
    'nestor',
    'nestorian',
    'nestorianism',
    'nestorius',
    'nests',
    'net',
    'netball',
    'nether',
    'netherlander',
    'netherlands',
    'nethermost',
    'netherworld',
    'netkeeper',
    'netlike',
    'netmail',
    'netminder',
    'nets',
    'netscape',
    'nett',
    'netted',
    'netting',
    'nettle',
    'nettled',
    'nettles',
    'nettlesome',
    'network',
    'networked',
    'networklike',
    'networks',
    'neumann',
    'neural',
    'neuralgia',
    'neuralgic',
    'neuralgy',
    'neurasthenia',
    'neurasthenic',
    'neurectomy',
    'neurilemma',
    'neurilemoma',
    'neurinoma',
    'neuritis',
    'neuroanatomic',
    'neuroanatomical',
    'neuroanatomy',
    'neurobiological',
    'neurobiologist',
    'neurobiology',
    'neuroblast',
    'neuroblastoma',
    'neurochemical',
    'neurodermatitis',
    'neuroendocrine',
    'neuroepithelioma',
    'neuroepithelium',
    'neuroethics',
    'neurofibroma',
    'neurofibromas',
    'neurofibromatosis',
    'neurogenesis',
    'neurogenic',
    'neuroglia',
    'neurogliacyte',
    'neuroglial',
    'neurohormone',
    'neurohypophysis',
    'neurolemma',
    'neuroleptic',
    'neurolinguist',
    'neurolinguistics',
    'neurologic',
    'neurological',
    'neurologist',
    'neurology',
    'neurolysin',
    'neuroma',
    'neuromarketing',
    'neuromas',
    'neuromatous',
    'neuromotor',
    'neuromuscular',
    'neuron',
    'neuronal',
    'neuronic',
    'neurons',
    'neurontin',
    'neuropathy',
    'neurophysiological',
    'neurophysiology',
    'neuropil',
    'neuropile',
    'neuroplasty',
    'neuropsychiatric',
    'neuropsychiatry',
    'neuropsychological',
    'neuropsychology',
    'neuroptera',
    'neuropteran',
    'neuropteron',
    'neurosarcoma',
    'neuroscience',
    'neuroscientist',
    'neurosis',
    'neurospora',
    'neurosurgeon',
    'neurosurgery',
    'neurosyphilis',
    'neurotic',
    'neuroticism',
    'neurotoxic',
    'neurotoxin',
    'neurotoxins',
    'neurotransmitter',
    'neurotrichus',
    'neurotropic',
    'neurotropism',
    'neuter',
    'neutered',
    'neutering',
    'neutral',
    'neutralisation',
    'neutralise',
    'neutralised',
    'neutralism',
    'neutralist',
    'neutrality',
    'neutralization',
    'neutralize',
    'neutralized',
    'neutralizes',
    'neutralizing',
    'neutrals',
    'neutrino',
    'neutrinos',
    'neutron',
    'neutrons',
    'neutropenia',
    'neutrophil',
    'neutrophile',
    'neutrophils',
    'neva',
    'nevada',
    'nevadan',
    'neve',
    'nevelson',
    'never',
    'nevirapine',
    'nevis',
    'nevus',
    'new',
    'newari',
    'newark',
    'newbie',
    'newborn',
    'newburg',
    'newburgh',
    'newcastle',
    'newcomb',
    'newcomer',
    'newcomers',
    'newel',
    'newest',
    'newfangled',
    'newfound',
    'newfoundland',
    'newgate',
    'newly',
    'newlywed',
    'newman',
    'newmarket',
    'newness',
    'newport',
    'news',
    'newsagent',
    'newsboy',
    'newsbreak',
    'newscast',
    'newscaster',
    'newsdealer',
    'newsflash',
    'newsless',
    'newsletter',
    'newsman',
    'newsmonger',
    'newspaper',
    'newspapering',
    'newspaperman',
    'newspapermen',
    'newspapers',
    'newspaperwoman',
    'newspeak',
    'newsperson',
    'newsprint',
    'newsreader',
    'newsreel',
    'newsroom',
    'newssheet',
    'newsstand',
    'newsvendor',
    'newsweek',
    'newswoman',
    'newsworthiness',
    'newsworthy',
    'newswriter',
    'newsy',
    'newt',
    'newton',
    'newtonian',
    'newtons',
    'newts',
    'next',
    'nexus',
    'ney',
    'nez',
    'ng',
    'nga',
    'nganasan',
    'ngb',
    'ngf',
    'ngo',
    'ngu',
    'ngultrum',
    'nguni',
    'ngwee',
    'nh',
    'ni',
    'niacin',
    'niagara',
    'niamey',
    'nib',
    'nibbed',
    'nibble',
    'nibbled',
    'nibbler',
    'nibbling',
    'nibelung',
    'nibelungenlied',
    'nibelungs',
    'niblick',
    'nibs',
    'nicad',
    'nicaea',
    'nicaean',
    'nicandra',
    'nicaragua',
    'nicaraguan',
    'nice',
    'nicely',
    'nicene',
    'niceness',
    'nicety',
    'niche',
    'niches',
    'nicholas',
    'nichrome',
    'nick',
    'nicked',
    'nickel',
    'nickelodeon',
    'nicker',
    'nicklaus',
    'nicknack',
    'nickname',
    'nicknames',
    'nicola',
    'nicolo',
    'nicolson',
    'nicosia',
    'nicotiana',
    'nicotine',
    'nicotinic',
    'nictate',
    'nictation',
    'nictitate',
    'nictitating',
    'nictitation',
    'nicu',
    'nidaros',
    'nidation',
    'niddm',
    'nidicolous',
    'nidifugous',
    'nidularia',
    'nidulariaceae',
    'nidulariales',
    'nidus',
    'niebuhr',
    'niece',
    'niels',
    'nielsen',
    'nierembergia',
    'nietzsche',
    'nifedipine',
    'niff',
    'niffy',
    'nifty',
    'nigella',
    'niger',
    'nigeria',
    'nigerian',
    'nigerien',
    'niggard',
    'niggardliness',
    'niggardly',
    'niggardness',
    'niggle',
    'niggler',
    'niggling',
    'nigh',
    'night',
    'nightbird',
    'nightcap',
    'nightclothes',
    'nightclub',
    'nightclubs',
    'nightcrawler',
    'nightdress',
    'nighted',
    'nightfall',
    'nightgown',
    'nighthawk',
    'nightie',
    'nightingale',
    'nightingales',
    'nightjar',
    'nightlife',
    'nightlong',
    'nightly',
    'nightmare',
    'nightmares',
    'nightmarish',
    'nightrider',
    'nights',
    'nightshade',
    'nightshirt',
    'nightspot',
    'nightstick',
    'nighttime',
    'nightwalker',
    'nightwear',
    'nightwork',
    'nigroporus',
    'nih',
    'nihau',
    'nihil',
    'nihilism',
    'nihilist',
    'nihilistic',
    'nihility',
    'nihon',
    'nij',
    'nijinsky',
    'nijmegen',
    'nike',
    'nil',
    'nile',
    'nilgai',
    'nilgais',
    'nilgiri',
    'nilotic',
    'nilpotent',
    'nilsson',
    'nim',
    'nimble',
    'nimbleness',
    'nimblewill',
    'nimbly',
    'nimbus',
    'nimby',
    'nimiety',
    'nimitz',
    'nimravus',
    'nimrod',
    'nina',
    'nincompoop',
    'nine',
    'ninefold',
    'ninepence',
    'ninepenny',
    'ninepin',
    'ninepins',
    'niner',
    'nineteen',
    'nineteenth',
    'nineties',
    'ninetieth',
    'ninety',
    'nineveh',
    'ning',
    'ningal',
    'ningirsu',
    'ningishzida',
    'ninhursag',
    'ninib',
    'ninigi',
    'ninja',
    'ninjitsu',
    'ninjutsu',
    'ninkharsag',
    'ninkhursag',
    'ninny',
    'nino',
    'ninon',
    'ninth',
    'nintoo',
    'nintu',
    'ninurta',
    'niobe',
    'niobite',
    'niobium',
    'niobrara',
    'nip',
    'nipa',
    'nipper',
    'nipping',
    'nipple',
    'nipples',
    'nippon',
    'nipponese',
    'nippy',
    'nipr',
    'niqaabi',
    'niqab',
    'nirvana',
    'nisan',
    'nisei',
    'nisi',
    'nissan',
    'nist',
    'nisus',
    'nit',
    'nitella',
    'niter',
    'nitid',
    'nitpick',
    'nitpicker',
    'nitramine',
    'nitrate',
    'nitrates',
    'nitrating',
    'nitrazepam',
    'nitre',
    'nitric',
    'nitride',
    'nitrification',
    'nitrify',
    'nitril',
    'nitrile',
    'nitrite',
    'nitrites',
    'nitro',
    'nitrobacter',
    'nitrobacteria',
    'nitrobacteriaceae',
    'nitrobacterium',
    'nitrobenzene',
    'nitrocalcite',
    'nitrocellulose',
    'nitrochloroform',
    'nitrochloromethane',
    'nitrocotton',
    'nitrofuran',
    'nitrofurantoin',
    'nitrogen',
    'nitrogenase',
    'nitrogenise',
    'nitrogenize',
    'nitrogenous',
    'nitroglycerin',
    'nitroglycerine',
    'nitrosobacteria',
    'nitrosomonas',
    'nitrospan',
    'nitrostat',
    'nitrous',
    'nitta',
    'nitweed',
    'nitwit',
    'nitwitted',
    'nivose',
    'nix',
    'nixed',
    'nixon',
    'nj',
    'njord',
    'njorth',
    'nlp',
    'nlrb',
    'nm',
    'nmr',
    'nne',
    'nnrti',
    'nnw',
    'no',
    'noaa',
    'noachian',
    'noah',
    'nob',
    'nobble',
    'nobel',
    'nobelist',
    'nobelium',
    'nobility',
    'noble',
    'nobleman',
    'noblemen',
    'nobleness',
    'nobles',
    'noblesse',
    'noblewoman',
    'nobody',
    'noc',
    'nocent',
    'nociceptive',
    'nock',
    'noctambulation',
    'noctambulism',
    'noctambulist',
    'noctiluca',
    'noctilucent',
    'noctua',
    'noctuid',
    'noctuidae',
    'nocturia',
    'nocturnal',
    'nocturnally',
    'nocturne',
    'nod',
    'nodded',
    'nodding',
    'noddle',
    'node',
    'nodes',
    'nodular',
    'nodulated',
    'nodule',
    'noduled',
    'nodules',
    'nodulose',
    'noel',
    'noemi',
    'noesis',
    'noether',
    'noetic',
    'nog',
    'nogales',
    'noggin',
    'nogging',
    'noguchi',
    'noir',
    'noise',
    'noiseless',
    'noiselessness',
    'noisemaker',
    'noises',
    'noisily',
    'noisiness',
    'noisome',
    'noisomeness',
    'noisy',
    'nolina',
    'nolle',
    'nolo',
    'noma',
    'nomad',
    'nomadic',
    'nomads',
    'nombril',
    'nome',
    'nomenclature',
    'nomenklatura',
    'nomia',
    'nominal',
    'nominalism',
    'nominalist',
    'nominalistic',
    'nominally',
    'nominate',
    'nominated',
    'nomination',
    'nominative',
    'nominator',
    'nominee',
    'nominees',
    'nomogram',
    'nomograph',
    'nomothetic',
    'nonabsorbency',
    'nonabsorbent',
    'nonabsorptive',
    'nonacceptance',
    'nonaccomplishment',
    'nonachievement',
    'nonachiever',
    'nonadaptive',
    'nonaddictive',
    'nonadhesive',
    'nonadjacent',
    'nonadsorbent',
    'nonadsorptive',
    'nonage',
    'nonaged',
    'nonagenarian',
    'nonaggression',
    'nonaggressive',
    'nonagon',
    'nonalcoholic',
    'nonaligned',
    'nonalignment',
    'nonalinement',
    'nonallele',
    'nonappearance',
    'nonappointive',
    'nonarbitrable',
    'nonarbitrary',
    'nonarboreal',
    'nonassertive',
    'nonassociative',
    'nonastringent',
    'nonattendance',
    'nonattender',
    'nonautonomous',
    'nonbearing',
    'nonbeing',
    'nonbeliever',
    'nonbelligerent',
    'noncaloric',
    'noncandidate',
    'noncarbonated',
    'noncausal',
    'noncausative',
    'nonce',
    'noncellular',
    'nonchalance',
    'nonchalant',
    'nonchalantly',
    'nonchristian',
    'nonchurchgoing',
    'noncitizen',
    'noncivilised',
    'noncivilized',
    'nonclassical',
    'noncollapsable',
    'noncollapsible',
    'noncolumned',
    'noncom',
    'noncombatant',
    'noncombinative',
    'noncombining',
    'noncombustible',
    'noncommercial',
    'noncommissioned',
    'noncommittal',
    'noncommunicable',
    'noncompetitive',
    'noncompliance',
    'noncompliant',
    'noncomprehensive',
    'nonconcentric',
    'nonconducting',
    'nonconductive',
    'nonconductor',
    'nonconformance',
    'nonconforming',
    'nonconformism',
    'nonconformist',
    'nonconformity',
    'nonconscious',
    'noncontagious',
    'noncontentious',
    'noncontinuous',
    'noncontroversial',
    'nonconvergent',
    'noncritical',
    'noncrucial',
    'noncrystalline',
    'noncurrent',
    'noncyclic',
    'noncyclical',
    'nondeductible',
    'nondenominational',
    'nondescript',
    'nondevelopment',
    'nondigestible',
    'nondisjunction',
    'nondisposable',
    'nondollar',
    'nondrinker',
    'nondriver',
    'none',
    'nonechoic',
    'noneconomist',
    'noneffervescent',
    'nonelected',
    'nonelective',
    'nonenterprising',
    'nonentity',
    'nonenzymatic',
    'nonequivalence',
    'nonequivalent',
    'nones',
    'nonessential',
    'nonesuch',
    'nonetheless',
    'nonevent',
    'nonexempt',
    'nonexistence',
    'nonexistent',
    'nonexplorative',
    'nonexploratory',
    'nonexplosive',
    'nonextant',
    'nonextensile',
    'nonfat',
    'nonfatal',
    'nonfeasance',
    'nonfiction',
    'nonfictional',
    'nonfigurative',
    'nonfinancial',
    'nonfinite',
    'nonfissile',
    'nonfissionable',
    'nonflammable',
    'nonflavored',
    'nonflavoured',
    'nonflowering',
    'nonfunctional',
    'nonglutinous',
    'nongovernmental',
    'nongranular',
    'nongregarious',
    'nonhairy',
    'nonharmonic',
    'nonhereditary',
    'nonheritable',
    'nonhierarchic',
    'nonhierarchical',
    'nonhuman',
    'nonimitative',
    'nonimmune',
    'nonindulgence',
    'nonindulgent',
    'nonindustrial',
    'noninfectious',
    'noninflammatory',
    'noninheritable',
    'noninstitutional',
    'noninstitutionalised',
    'noninstitutionalized',
    'nonintegrated',
    'nonintellectual',
    'noninterchangeable',
    'noninterference',
    'nonintersecting',
    'nonintervention',
    'noninvasive',
    'nonionic',
    'nonionised',
    'nonionized',
    'nonjudgmental',
    'nonkosher',
    'nonleaded',
    'nonlegal',
    'nonlethal',
    'nonlexical',
    'nonlinear',
    'nonlinguistic',
    'nonliteral',
    'nonliterary',
    'nonliterate',
    'nonliving',
    'nonmagnetic',
    'nonmalignant',
    'nonmandatory',
    'nonmaterial',
    'nonmeaningful',
    'nonmechanical',
    'nonmechanistic',
    'nonmedicinal',
    'nonmember',
    'nonmembers',
    'nonmetal',
    'nonmetallic',
    'nonmetamorphic',
    'nonmigratory',
    'nonmilitary',
    'nonmodern',
    'nonmonotonic',
    'nonmotile',
    'nonmoving',
    'nonmusical',
    'nonnative',
    'nonnatural',
    'nonnegative',
    'nonnomadic',
    'nonnormative',
    'nonobjective',
    'nonobligatory',
    'nonobservance',
    'nonobservant',
    'nonoccurrence',
    'nonopening',
    'nonoperational',
    'nonoscillatory',
    'nonparallel',
    'nonparametric',
    'nonparasitic',
    'nonpareil',
    'nonparticipant',
    'nonparticipation',
    'nonparticulate',
    'nonpartisan',
    'nonpartisanship',
    'nonpartizan',
    'nonpasserine',
    'nonpayment',
    'nonperformance',
    'nonperiodic',
    'nonperson',
    'nonpersonal',
    'nonphotosynthetic',
    'nonphysical',
    'nonplus',
    'nonplused',
    'nonplussed',
    'nonpoisonous',
    'nonpolar',
    'nonpolitical',
    'nonporous',
    'nonpregnant',
    'nonprehensile',
    'nonproductive',
    'nonprofessional',
    'nonprofit',
    'nonprognosticative',
    'nonprogressive',
    'nonproliferation',
    'nonproprietary',
    'nonprotractile',
    'nonpsychoactive',
    'nonpublic',
    'nonpurulent',
    'nonracial',
    'nonracist',
    'nonradioactive',
    'nonrandom',
    'nonrational',
    'nonreader',
    'nonreciprocal',
    'nonreciprocating',
    'nonrecreational',
    'nonreflecting',
    'nonreflective',
    'nonremittal',
    'nonrenewable',
    'nonrepetitive',
    'nonrepresentational',
    'nonrepresentative',
    'nonresident',
    'nonresidential',
    'nonresilient',
    'nonresinous',
    'nonresiny',
    'nonresistance',
    'nonresistant',
    'nonresonant',
    'nonrestrictive',
    'nonreticulate',
    'nonretractable',
    'nonretractile',
    'nonreturnable',
    'nonreversible',
    'nonrhythmic',
    'nonrigid',
    'nonruminant',
    'nonsectarian',
    'nonsegmental',
    'nonsegregated',
    'nonsense',
    'nonsensical',
    'nonsensicality',
    'nonsensitive',
    'nonsexual',
    'nonsignificant',
    'nonskid',
    'nonslip',
    'nonslippery',
    'nonsmoker',
    'nonsocial',
    'nonsovereign',
    'nonspatial',
    'nonspeaking',
    'nonspecific',
    'nonspherical',
    'nonstandard',
    'nonstarter',
    'nonsteroid',
    'nonsteroidal',
    'nonstick',
    'nonstop',
    'nonstops',
    'nonstriking',
    'nonstructural',
    'nonsubjective',
    'nonsubmergible',
    'nonsubmersible',
    'nonsuch',
    'nonsuppurative',
    'nonsurgical',
    'nonsweet',
    'nonsyllabic',
    'nonsymbiotic',
    'nonsynchronous',
    'nonsynthetic',
    'nontaxable',
    'nontechnical',
    'nontelescopic',
    'nontelescoping',
    'nonterritorial',
    'nonthermal',
    'nontoxic',
    'nontraditional',
    'nontransferable',
    'nontranslational',
    'nontransmissible',
    'nontricyclic',
    'nonturbulent',
    'nonuniform',
    'nonuniformity',
    'nonunion',
    'nonunionised',
    'nonunionized',
    'nonuple',
    'nonvascular',
    'nonvenomous',
    'nonverbal',
    'nonverbally',
    'nonviable',
    'nonviolence',
    'nonviolent',
    'nonviscid',
    'nonvisual',
    'nonvolatile',
    'nonvolatilisable',
    'nonvolatilizable',
    'nonvoluntary',
    'nonwashable',
    'nonwoody',
    'nonworker',
    'noodle',
    'noodles',
    'nook',
    'nookie',
    'nooky',
    'noon',
    'noonday',
    'noontide',
    'noose',
    'noosed',
    'nootka',
    'nopal',
    'nopalea',
    'nor',
    'noradrenaline',
    'nordhoff',
    'nordic',
    'noreaster',
    'noreg',
    'norepinephrine',
    'norethandrolone',
    'norethindrone',
    'norethynodrel',
    'norflex',
    'norfolk',
    'norgay',
    'norge',
    'norgestrel',
    'noria',
    'norinyl',
    'norlestrin',
    'norlutin',
    'norm',
    'norma',
    'normal',
    'normalcy',
    'normalisation',
    'normalise',
    'normaliser',
    'normality',
    'normalization',
    'normalize',
    'normalizer',
    'normalizes',
    'normalizing',
    'normally',
    'norman',
    'normandie',
    'normandy',
    'normans',
    'normative',
    'normodyne',
    'normon',
    'normotensive',
    'normothermia',
    'norms',
    'norn',
    'norns',
    'norris',
    'norrish',
    'norse',
    'norseman',
    'norsemen',
    'north',
    'northampton',
    'northamptonshire',
    'northbound',
    'northcote',
    'northeast',
    'northeaster',
    'northeasterly',
    'northeastern',
    'northeastward',
    'northeastwardly',
    'norther',
    'northerly',
    'northern',
    'northerner',
    'northernmost',
    'northernness',
    'northland',
    'northman',
    'northmost',
    'northrop',
    'northumberland',
    'northumbria',
    'northward',
    'northwest',
    'northwester',
    'northwesterly',
    'northwestern',
    'northwestward',
    'nortriptyline',
    'noruz',
    'norvasc',
    'norvir',
    'norway',
    'norwegian',
    'nose',
    'nosebag',
    'noseband',
    'nosebleed',
    'nosebleeds',
    'nosecount',
    'nosed',
    'nosedive',
    'nosegay',
    'noseless',
    'nosepiece',
    'noses',
    'nosewheel',
    'nosey',
    'nosh',
    'nosher',
    'nosiness',
    'nosing',
    'nosocomial',
    'nosohusial',
    'nosology',
    'nostalgia',
    'nostalgic',
    'nostoc',
    'nostocaceae',
    'nostradamus',
    'nostril',
    'nostrils',
    'nostrum',
    'nosy',
    'not',
    'notability',
    'notable',
    'notably',
    'notarise',
    'notarize',
    'notary',
    'notate',
    'notated',
    'notation',
    'notch',
    'notched',
    'notches',
    'notching',
    'note',
    'notebook',
    'notebooks',
    'notecase',
    'notechis',
    'noted',
    'notemigonus',
    'notepad',
    'notepaper',
    'notes',
    'noteworthy',
    'nothing',
    'nothingness',
    'nothings',
    'nothofagus',
    'nothosaur',
    'nothosauria',
    'nothosaurs',
    'notice',
    'noticeability',
    'noticeable',
    'noticeableness',
    'noticeably',
    'noticed',
    'noticer',
    'notices',
    'noticing',
    'notifiable',
    'notification',
    'notify',
    'notifying',
    'noting',
    'notion',
    'notional',
    'notions',
    'notochord',
    'notomys',
    'notonecta',
    'notonectidae',
    'notophthalmus',
    'notoriety',
    'notorious',
    'notoriously',
    'notornis',
    'notoryctidae',
    'notoryctus',
    'notostraca',
    'notropis',
    'notturno',
    'nouakchott',
    'nougat',
    'nought',
    'noumenon',
    'noun',
    'nouns',
    'nourish',
    'nourished',
    'nourishes',
    'nourishing',
    'nourishment',
    'nous',
    'nouveau',
    'nov',
    'nova',
    'novate',
    'novation',
    'novel',
    'novelette',
    'novelisation',
    'novelise',
    'novelist',
    'novelists',
    'novelization',
    'novelize',
    'novelized',
    'novella',
    'novels',
    'novelty',
    'november',
    'novena',
    'novgorod',
    'novial',
    'novice',
    'noviciate',
    'novillada',
    'novillero',
    'novitiate',
    'novobiocin',
    'novocain',
    'novocaine',
    'novosibirsk',
    'now',
    'nowadays',
    'nowhere',
    'nowness',
    'nowrooz',
    'nowruz',
    'nox',
    'noxious',
    'noxiousness',
    'noyes',
    'nozzle',
    'nozzles',
    'np',
    'npa',
    'npc',
    'nra',
    'nrc',
    'nrem',
    'nrl',
    'nrna',
    'nro',
    'nrti',
    'nsa',
    'nsaid',
    'nsaids',
    'nsc',
    'nsf',
    'nsu',
    'nsw',
    'nswc',
    'nt',
    'nth',
    'ntis',
    'nu',
    'nuance',
    'nuances',
    'nub',
    'nubbin',
    'nubbiness',
    'nubble',
    'nubbly',
    'nubby',
    'nubia',
    'nubian',
    'nubile',
    'nucellus',
    'nucha',
    'nucifraga',
    'nuclear',
    'nuclease',
    'nucleate',
    'nucleated',
    'nuclei',
    'nucleic',
    'nucleole',
    'nucleolus',
    'nucleon',
    'nucleonics',
    'nucleoplasm',
    'nucleoprotein',
    'nucleoside',
    'nucleosynthesis',
    'nucleotide',
    'nucleotides',
    'nucleus',
    'nuda',
    'nude',
    'nudeness',
    'nudes',
    'nudge',
    'nudged',
    'nudger',
    'nudibranch',
    'nudibranchia',
    'nudism',
    'nudist',
    'nudity',
    'nudnick',
    'nudnik',
    'nuffield',
    'nugatory',
    'nugget',
    'nuggets',
    'nuisance',
    'nuke',
    'null',
    'nullah',
    'nullarbor',
    'nullification',
    'nullified',
    'nullifier',
    'nullify',
    'nullipara',
    'nullity',
    'numb',
    'numbat',
    'numbed',
    'number',
    'numbered',
    'numbering',
    'numberless',
    'numberplate',
    'numbers',
    'numbfish',
    'numbing',
    'numbness',
    'numbs',
    'numdah',
    'numen',
    'numenius',
    'numerable',
    'numeracy',
    'numeral',
    'numerals',
    'numerate',
    'numeration',
    'numerator',
    'numeric',
    'numerical',
    'numerically',
    'numerological',
    'numerologist',
    'numerology',
    'numerosity',
    'numerous',
    'numerousness',
    'numida',
    'numidia',
    'numidian',
    'numididae',
    'numidinae',
    'numinous',
    'numismatics',
    'numismatist',
    'numismatologist',
    'numismatology',
    'nummulite',
    'nummulitidae',
    'numskull',
    'nun',
    'nunavut',
    'nuncio',
    'nung',
    'nunnery',
    'nuns',
    'nuphar',
    'nuprin',
    'nuptial',
    'nuptials',
    'nuptse',
    'nuremberg',
    'nureyev',
    'nurnberg',
    'nurse',
    'nursed',
    'nurseling',
    'nursemaid',
    'nursemaids',
    'nurser',
    'nursery',
    'nurseryman',
    'nurses',
    'nursing',
    'nursling',
    'nurtural',
    'nurturance',
    'nurturant',
    'nurture',
    'nurtured',
    'nurtures',
    'nurturing',
    'nusku',
    'nut',
    'nutate',
    'nutation',
    'nutbrown',
    'nutcase',
    'nutcracker',
    'nutcrackers',
    'nutgrass',
    'nuthatch',
    'nuthatches',
    'nuthouse',
    'nutlet',
    'nutlets',
    'nutlike',
    'nutmeg',
    'nutria',
    'nutrient',
    'nutrients',
    'nutrify',
    'nutriment',
    'nutrition',
    'nutritional',
    'nutritionally',
    'nutritionary',
    'nutritionist',
    'nutritionists',
    'nutritious',
    'nutritiousness',
    'nutritive',
    'nutritiveness',
    'nuts',
    'nutsedge',
    'nutshell',
    'nutter',
    'nutty',
    'nuwc',
    'nux',
    'nuytsia',
    'nuzzle',
    'nuzzled',
    'nv',
    'nw',
    'nwbn',
    'nwbw',
    'ny',
    'nyala',
    'nyamuragira',
    'nyamwezi',
    'nyasaland',
    'nybble',
    'nyctaginaceae',
    'nyctaginia',
    'nyctalopia',
    'nyctanassa',
    'nyctereutes',
    'nycticebus',
    'nycticorax',
    'nyctimene',
    'nyctophobia',
    'nycturia',
    'nydrazid',
    'nyiragongo',
    'nylghai',
    'nylghau',
    'nylon',
    'nylons',
    'nymph',
    'nymphaea',
    'nymphaeaceae',
    'nymphalid',
    'nymphalidae',
    'nymphalis',
    'nymphet',
    'nymphicus',
    'nympho',
    'nympholepsy',
    'nympholept',
    'nymphomania',
    'nymphomaniac',
    'nymphomaniacal',
    'nymphs',
    'nynorsk',
    'nypa',
    'nyse',
    'nyssa',
    'nyssaceae',
    'nystagmus',
    'nystan',
    'nystatin',
    'nyx']



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Convert Delimiters into Periods """


from lingpatlab.baseblock import BaseObject


class DelimitersToPeriods(BaseObject):
    """ Convert Delimiters into Periods """

    def __init__(self):
        """
        Created:
            30-Sept-2021
            craigtrim@gmail.com
            *   created
        Updated:
            27-Mar-2024
            craigtrim@gmail.com
            *   migrated out of modai in pursuit of
                https://github.com/craigtrim/datapipe-apis/issues/72
        """
        BaseObject.__init__(self, __name__)

    @staticmethod
    def process(input_text: str,
                delimiter: str):
        """
        Purpose:
            Take a CSV list and transform to sentences
        :param input_text:
        :return:
        """
        total_len = len(input_text)
        total_delims = input_text.count(delimiter)

        if total_delims == 0:
            return input_text

        if total_delims / total_len > 0.04:
            return input_text.replace(delimiter, '.')

        return input_text



class PorterStemmer:
    def __init__(self):
        self._vowels = 'aeiou'
        self._step1_suffixes = ['sses', 'ies', 'ss', 's']
        self._step2_suffixes = ['eed', 'ed', 'ing']
        self._step3_suffixes = ['at', 'bl', 'iz']
        self._step4_suffixes = ['ational', 'tional', 'enci', 'anci', 'izer', 'bli', 'alli', 'entli', 'eli', 'ousli',
                                'ization', 'ation', 'ator', 'alism', 'iveness', 'fulness', 'ousness', 'aliti', 'iviti',
                                'biliti', 'logi']
        self._step5a_suffixes = ['icate', 'ative',
                                 'alize', 'iciti', 'ical', 'ful', 'ness']
        self._step5b_suffixes = ['al', 'ance', 'ence', 'er', 'ic', 'able', 'ible', 'ant', 'ement', 'ment', 'ent',
                                 'ou', 'ism', 'ate', 'iti', 'ous', 'ive', 'ize']

    def _get_measure(self, word: str) -> int:
        """Calculate the measure m of a word."""
        vowels = self._vowels
        word = word.lower()
        num_vowels = sum((char in vowels) for char in word)
        measure = 0
        prev_char_was_vowel = False
        for char in word:
            if char in vowels:
                if not prev_char_was_vowel:
                    measure += 1
                    prev_char_was_vowel = True
            else:
                prev_char_was_vowel = False
        return num_vowels, measure

    def _replace_suffix(self, word: str, suffix: str, replacement: str) -> str:
        """Replace a suffix of a word if the measure of the resulting word is > 0."""
        if word.endswith(suffix):
            stem = word[:-len(suffix)]
            if self._get_measure(stem)[1] > 0:
                return stem + replacement
        return word

    def stem(self, word: str) -> str:
        """Stem a word using the Porter Stemmer algorithm."""
        if len(word) <= 2:
            return word

        # Step 1
        for suffix in self._step1_suffixes:
            if word.endswith(suffix):
                return self._replace_suffix(word, suffix, '')

        # Step 2
        if word.endswith('y'):
            stem = word[:-1]
            if self._get_measure(stem)[1] > 0:
                return stem + 'i'
            else:
                return word
        for suffix in self._step2_suffixes:
            if word.endswith(suffix):
                stem = word[:-len(suffix)]
                if self._get_measure(stem)[1] > 0:
                    return stem
                else:
                    return word

        # Step 3
        for suffix in self._step3_suffixes:
            if word.endswith(suffix):
                return self._replace_suffix(word, suffix, 'e')

        # Step 4
        for suffix in self._step4_suffixes:
            if word.endswith(suffix):
                return self._replace_suffix(word, suffix, '')

        # Step 5a
        for suffix in self._step5a_suffixes:
            if word.endswith(suffix):
                return self._replace_suffix(word, suffix, '')

        # Step 5b
        for suffix in self._step5b_suffixes:
            if word.endswith(suffix):
                stem = word[:-len(suffix)]
                if self._get_measure(stem)[1] > 1:
                    return stem
                else:
                    return word

        return word



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['lingpatlab',
 'lingpatlab.analyze',
 'lingpatlab.analyze.bp',
 'lingpatlab.analyze.dmo',
 'lingpatlab.analyze.dto',
 'lingpatlab.analyze.svc',
 'lingpatlab.baseblock',
 'lingpatlab.parser',
 'lingpatlab.parser.dmo',
 'lingpatlab.parser.dto',
 'lingpatlab.parser.svc',
 'lingpatlab.segmenter',
 'lingpatlab.segmenter.bp',
 'lingpatlab.segmenter.dmo',
 'lingpatlab.segmenter.svc',
 'lingpatlab.tokenizer',
 'lingpatlab.tokenizer.bp',
 'lingpatlab.tokenizer.dmo',
 'lingpatlab.tokenizer.dto',
 'lingpatlab.tokenizer.svc',
 'lingpatlab.utils',
 'lingpatlab.utils.bp',
 'lingpatlab.utils.dmo',
 'lingpatlab.utils.dto',
 'lingpatlab.utils.os',
 'lingpatlab.utils.svc']

package_data = \
{'': ['*']}

install_requires = \
['spacy==3.8.2', 'unicodedata2']

setup_kwargs = {
    'name': 'lingpatlab',
    'version': '0.2.10',
    'description': 'Linguistic Pattern Lab using spaCy',
    'long_description': '# LingPatLab: Linguistic Pattern Laboratory\n\n## Overview\n\nLingPatLab is a robust API designed to perform advanced Natural Language Processing (NLP) tasks, utilizing the capabilities of the spaCy library. This tool is expertly crafted to convert raw textual data into structured, analyzable forms. It is ideal for developers, researchers, and linguists who require comprehensive processing capabilities, from tokenization to sophisticated text summarization.\n\n## Features\n\n- **Tokenization**: Splits raw text into individual tokens.\n- **Parsing**: Analyzes tokens to construct sentences with detailed linguistic annotations.\n- **Phrase Extraction**: Identifies and extracts significant phrases from sentences.\n- **Text Summarization**: Produces concise summaries of input text, optionally leveraging extracted phrases.\n\n## Usage\n\nTo get started with LingPatLab, you can set up the API as follows:\n\n```python\nfrom spacy_core.api import SpacyCoreAPI\n\napi = LingPatLab()\n```\n\n### Tokenization and Parsing\n\nTo tokenize and parse input text into structured sentences:\n\n```python\nparsed_sentence: Sentence = api.parse_input_text("Your input text here.")\nprint(parsed_sentence.to_string())\n```\n\n### Phrase Extraction\n\nTo extract phrases from a structured Sentences object:\n\n```python\nphrases: List[str] = api.extract_topics(parsed_sentences)\nfor phrase in phrases:\n    print(phrase)\n```\n\n### Summarization\n\nTo generate a summary of the input text:\n\n```python\nsummary: str = api.generate_summary("Your input text here.")\nprint(summary)\n```\n\n### Data Classes\n\nLingPatLab utilizes several custom data classes to structure the data throughout the NLP process:\n\n- `Sentence`: Represents a single sentence, containing a list of tokens (`SpacyResult` objects).\n- `Sentences`: Represents a collection of sentences, useful for processing paragraphs or multiple lines of text.\n- `SpacyResult`: Encapsulates the detailed analysis of a single token, including part of speech, dependency relations, and additional linguistic features.\n- `OtherInfo`: Contains additional information about a token, particularly in relation to its syntactic head.\n',
    'author': 'Craig Trim',
    'author_email': 'craigtrim@gmail.com',
    'maintainer': 'Craig Trim',
    'maintainer_email': 'craigtrim@gmail.com',
    'url': 'https://github.com/craigtrim/lingpatlab',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Use spaCy to Parse Input Tokens """


from typing import List
from spacy.lang.en import English

from lingpatlab.baseblock import (
    BaseObject,
    Stopwatch
)

from lingpatlab.parser.dmo import (
    TokenParserCoordinates,
    TokenParserNormalize,
    TokenParserPostProcess,
    TokenParserPunctuation,
    TokenParserResultSet,
    TokenParserSpacy,
    TokenParserSquots,
    TokenParserWordnet
)
from lingpatlab.utils.dto import (
    Sentence,
    SpacyResult,
)


class ParseInputTokens(BaseObject):
    """ Use spaCy to Parse Input Tokens """

    def __init__(self,
                 en_spacy_model: English | None = None):
        """ Change Log

        Created:
            1-Oct-2021
            craigtrim@gmail.com
        Updated:
            13-Oct-2021
            craigtrim@gmail.com
            *   refactored into component parts in pursuit of
                https://github.com/grafflr/graffl-core/issues/41
        Updated:
            16-Sept-2022
            craigtrim@gmail.com
            *   integrate 'token-parser-postprocess'
                https://github.com/craigtrim/spacy-token-parser/issues/3
            *   rename all components
                https://github.com/craigtrim/spacy-token-parser/issues/3
        Updated:
            29-Feb-2024
            craigtrim@gmail.com
            *   change dataflow
                https://github.com/craigtrim/datapipe-apis/issues/45
        Updated:
            16-Aug-2024
            craigtrim@gmail.com
            *   optimize model instantiation
            *   pre-init class methods in init function
                https://github.com/craigtrim/LingPatLab/issues/2
        """
        BaseObject.__init__(self, __name__)
        self._parse_squots = TokenParserSquots().process
        self._spacy_parse = TokenParserSpacy(en_spacy_model).process
        self._parse_result_set = TokenParserResultSet().process
        self._parse_punkt = TokenParserPunctuation().process
        self._normalize_parse = TokenParserNormalize().process
        self._parse_coords = TokenParserCoordinates().process
        self._parse_wordnet = TokenParserWordnet().process
        self._post_process = TokenParserPostProcess().process

    def process(self,
                tokens: List[str]) -> Sentence | None:

        sw = Stopwatch()

        tokens = self._parse_squots(tokens)
        if not tokens or not len(tokens):
            return None

        doc = self._spacy_parse(' '.join(tokens))

        results = self._parse_result_set(doc)
        if not results or not len(results):
            return None

        results = self._parse_punkt(results)
        if not results or not len(results):
            return None

        results = self._normalize_parse(results)
        if not results or not len(results):
            return None

        results = self._parse_coords(results)
        if not results or not len(results):
            return None

        results = self._parse_wordnet(results)
        if not results or not len(results):
            return None

        results = self._post_process(results)
        if not results or not len(results):
            return None

        sentence = Sentence([
            SpacyResult(**token) for token in results
        ])

        if self.isEnabledForDebug:
            self.logger.debug(
                f'Input Parsing Completed: (total-tokens={sentence.size()}), (total-time={str(sw)})')

        return sentence



# !/usr/bin/env python
# -*- coding: UTF-8 -*-

from typing import List, Optional


SYSTEM_PROMPT_SUMMARY = "You are a helpful assistant who summarizes text and maintains tonality."

SYSTEM_PROMPT_TEMPLATE_1 = """
You are a helpful assistant who summarizes text.

You must follow these rules:
1. Your summary must use all my phrases.
2. You CAN NOT change my phrases when you use them.
3. You must only output the summary.  
4. Do not use phrases like "the author recalls" or "the text describes".  
5. Your summary must not sound like a summary.
6. Your summary must have the same tone as the original text.

CONTENT TO SUMMARIZE:
```
#SUMMARY
```

MY PHRASES:
```
#PHRASES
```
        """

SYSTEM_PROMPT_TEMPLATE_2 = """
You are a helpful assistant who summarizes text.

You must follow these rules:
1. You must only output the summary.  
2. Do not use phrases like "the author recalls" or "the text describes".  
3. Your summary must not sound like a summary.
4. Your summary must have the same tone as the original text.
5. Use phrases found in the original text for your summary.

CONTENT TO SUMMARIZE:
```
#SUMMARY
```
"""

SYSTEM_PROMPT_TEMPLATE_2 = """
You are a helpful assistant who condenses text.

You must follow these rules:
1. Subject-Verb Agreement: Ensure subjects and verbs match in number.
2. Proper Pronoun Usage: Match pronouns with their antecedents in gender, number, and person.
3. Sentence Structure: Maintain clear subject-verb-object order.
4. Active vs. Passive Voice: Prefer active voice for clarity and directness.
5. Tense Consistency: Use tenses consistently to indicate timing accurately.
6. Anaphora Resolution: Resolve anaphoric references to ensure clarity and coherence within a text.
7. Acronym Resolution: Clarify the meaning of acronyms when their definitions are provided in the text for better understanding.

CONTENT TO CONDENSE:
```
#SUMMARY
```
"""


SAMPLE_ORIGINAL_TEXT = """004-030": "hold your head up high. \"The Sounds of Silence\" over and over in my head: \"The words of the prophets are written on the subway walls and tenement halls.\" In \"Thinking in Pictures,\" I wrote about Led Zeppelin's \"Stairway to Heaven,\" which I listened to while driving away from the meat-packing plants. But the music I've loved since I was a child comes from musicals. I loved them then, and I love them now. In high school, my roommate played Carousel, Bye Bye Birdie, and Oklahoma! over and over. I sang \"The Farmer and the Cowman\" from Oklahoma! in the high school talent show. And when I graduated, I recited the words to \"You'll Never Walk Alone\" from Carousel. It was a song that made me think about my future. There may be storms, but when you get through them, there will be a bright future. I have gone through many doors, and in walking through them, I always come back to this song and the promise of a golden sky. Composer Richard Rodgers and lyricist Oscar Hammerstein were the musical team behind many of my favorite musicals, including Carousel and Oklahoma! Looking into their collaboration, I realized they were the perfect example of complementary minds. When they met, Rodgers already had a highly successful Broadway career. Hammerstein wasn't quite as successful but was widely respected.\n\nIt wasn't common for theater people to start collaborating at midlife, but from the moment the two men decided to work together, something magical happened. In The Sound of Their Music, Frederick Nolan quotes Rodgers as saying, \"What happened between Oscar and me was almost chemical. Put the right components together and an explosion takes place. Oscar and I hit it off from the day we started discussing the show.\" When you walk through a storm.\n","""


SAMPLE_PHRASES = [
    'start collaborating at midlife',
    'started discussing the show',
    'lyricist oscar hammerstein',
    'roommate played carousel',
    'explosion takes place',
    'school talent show'
]


SAMPLE_OUTPUT = """
The love for musicals, deeply rooted since childhood, resurfaces. High school memories include roommates playing Carousel, Bye Bye Birdie, and Oklahoma! on repeat. Participating in the school talent show, "The Farmer and the Cowman" from Oklahoma! was sung. Graduation was marked by reciting "You'll Never Walk Alone" from Carousel, symbolizing hope for the future amidst storms. Reflecting on Richard Rodgers and lyricist Oscar Hammerstein's partnership reveals their complementary minds. Their collaboration, starting at midlife, led to a magical synergy, as expressed by Rodgers in the quote, "What happened between Oscar and me was almost chemical."
"""


def generate_sample_prompt() -> str:
    return generate_prompt(input_text=SAMPLE_ORIGINAL_TEXT, phrases=SAMPLE_PHRASES)


def generate_prompt(input_text: str, phrases: Optional[List[str]] = None) -> str:
    if phrases and len(phrases):
        return SYSTEM_PROMPT_TEMPLATE_1.replace('#SUMMARY', input_text).replace(
            '#PHRASES', ', '.join(phrases))
    return SYSTEM_PROMPT_TEMPLATE_2.replace('#SUMMARY', input_text)




#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_x_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.242458'}

wordnet_terms_x = [
    'xanax',
    'xanthate',
    'xanthelasma',
    'xanthemia',
    'xanthic',
    'xanthine',
    'xanthium',
    'xanthoma',
    'xanthomas',
    'xanthomatosis',
    'xanthomonad',
    'xanthomonas',
    'xanthophyceae',
    'xanthophyl',
    'xanthophyll',
    'xanthopsia',
    'xanthorrhoeaceae',
    'xanthorroea',
    'xanthosis',
    'xanthosoma',
    'xanthous',
    'xantusiidae',
    'xavier',
    'xbox',
    'xc',
    'xci',
    'xcii',
    'xciii',
    'xciv',
    'xcl',
    'xcv',
    'xcvi',
    'xcvii',
    'xcviii',
    'xe',
    'xenarthra',
    'xenicidae',
    'xenicus',
    'xenogeneic',
    'xenogenesis',
    'xenograft',
    'xenolith',
    'xenon',
    'xenophanes',
    'xenophobia',
    'xenophobic',
    'xenophon',
    'xenopodidae',
    'xenopus',
    'xenorhyncus',
    'xenosauridae',
    'xenosaurus',
    'xenotime',
    'xenotransplant',
    'xenotransplantation',
    'xeranthemum',
    'xeric',
    'xerobates',
    'xeroderma',
    'xerodermia',
    'xerographic',
    'xerography',
    'xeroma',
    'xerophile',
    'xerophthalmia',
    'xerophthalmus',
    'xerophyllum',
    'xerophyte',
    'xerophytes',
    'xerophytic',
    'xeroradiography',
    'xerostomia',
    'xerotes',
    'xerox',
    'xhosa',
    'xi',
    'xian',
    'xiao',
    'xii',
    'xiii',
    'xinjiang',
    'xiphias',
    'xiphiidae',
    'xiphosura',
    'xiv',
    'xix',
    'xizang',
    'xl',
    'xli',
    'xlii',
    'xliii',
    'xliv',
    'xlv',
    'xlvi',
    'xlvii',
    'xlviii',
    'xmas',
    'xt',
    'xtc',
    'xv',
    'xvi',
    'xvii',
    'xviii',
    'xx',
    'xxi',
    'xxii',
    'xxiii',
    'xxiv',
    'xxix',
    'xxv',
    'xxvi',
    'xxvii',
    'xxviii',
    'xxx',
    'xxxi',
    'xxxii',
    'xxxiii',
    'xxxiv',
    'xxxv',
    'xxxvi',
    'xxxvii',
    'xxxviii',
    'xxy',
    'xy',
    'xylaria',
    'xylariaceae',
    'xylem',
    'xylene',
    'xylocaine',
    'xylocopa',
    'xylol',
    'xylomelum',
    'xylophone',
    'xylophones',
    'xylophonist',
    'xylopia',
    'xylose',
    'xylosma',
    'xyphophorus',
    'xyridaceae',
    'xyridales',
    'xyris',
    'xyy']




#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_q_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.205958'}

wordnet_terms_q = [
    'qabala',
    'qabalah',
    'qabalistic',
    'qabbala',
    'qabbalah',
    'qaddafi',
    'qadhafi',
    'qadi',
    'qaeda',
    'qandahar',
    'qat',
    'qatar',
    'qatari',
    'qcd',
    'qed',
    'qepiq',
    'qi',
    'qiang',
    'qiangic',
    'qibla',
    'qin',
    'qindarka',
    'qing',
    'qintar',
    'qoph',
    'quaalude',
    'quack',
    'quackery',
    'quackgrass',
    'quacking',
    'quad',
    'quadragesima',
    'quadrangle',
    'quadrangles',
    'quadrangular',
    'quadrant',
    'quadrantanopia',
    'quadraphonic',
    'quadraphony',
    'quadrasonic',
    'quadrate',
    'quadratic',
    'quadratics',
    'quadrature',
    'quadrennium',
    'quadric',
    'quadriceps',
    'quadrilateral',
    'quadrilaterals',
    'quadrille',
    'quadrillion',
    'quadrillionth',
    'quadripara',
    'quadripartite',
    'quadriphonic',
    'quadriplegia',
    'quadriplegic',
    'quadrisonic',
    'quadrivium',
    'quadroon',
    'quadrumvirate',
    'quadruped',
    'quadrupedal',
    'quadrupeds',
    'quadruple',
    'quadruplet',
    'quadruplex',
    'quadruplicate',
    'quadrupling',
    'quaestor',
    'quaff',
    'quaffed',
    'quaffer',
    'quag',
    'quagga',
    'quaggy',
    'quagmire',
    'quahaug',
    'quahog',
    'quail',
    'quaint',
    'quaintness',
    'quake',
    'quaker',
    'quakerism',
    'quakers',
    'quakes',
    'quaking',
    'qualification',
    'qualifications',
    'qualified',
    'qualifier',
    'qualifies',
    'qualify',
    'qualifying',
    'qualitative',
    'qualities',
    'quality',
    'qualm',
    'quamash',
    'quamassia',
    'quandang',
    'quandary',
    'quandong',
    'quango',
    'quanta',
    'quantal',
    'quantic',
    'quantifiability',
    'quantifiable',
    'quantification',
    'quantified',
    'quantifier',
    'quantifiers',
    'quantify',
    'quantisation',
    'quantise',
    'quantitative',
    'quantities',
    'quantity',
    'quantization',
    'quantize',
    'quantized',
    'quantong',
    'quantum',
    'quaoar',
    'quapaw',
    'quarantine',
    'quarantined',
    'quark',
    'quarks',
    'quarrel',
    'quarreled',
    'quarreler',
    'quarreling',
    'quarrelled',
    'quarreller',
    'quarrels',
    'quarrelsome',
    'quarrelsomeness',
    'quarrier',
    'quarries',
    'quarry',
    'quarrying',
    'quarryman',
    'quart',
    'quartan',
    'quarter',
    'quarterback',
    'quarterdeck',
    'quartered',
    'quarterfinal',
    'quartering',
    'quarterlight',
    'quarterly',
    'quartermaster',
    'quartern',
    'quarters',
    'quarterstaff',
    'quartervine',
    'quartet',
    'quartette',
    'quartic',
    'quartile',
    'quarto',
    'quarts',
    'quartz',
    'quartzite',
    'quartzose',
    'quasar',
    'quash',
    'quashes',
    'quasi',
    'quasiparticle',
    'quassia',
    'quat',
    'quatercentenary',
    'quatercentennial',
    'quatern',
    'quaternary',
    'quaternate',
    'quaternion',
    'quaternity',
    'quatrain',
    'quatrains',
    'quattrocento',
    'quaver',
    'quavering',
    'quay',
    'quayage',
    'queasiness',
    'queasy',
    'quebec',
    'quebecois',
    'quechua',
    'quechuan',
    'queen',
    'queenfish',
    'queenlike',
    'queenly',
    'queens',
    'queensland',
    'queer',
    'queerness',
    'quell',
    'quelled',
    'quelling',
    'quellung',
    'quench',
    'quenched',
    'quenching',
    'quenchless',
    'quercitron',
    'quercus',
    'querier',
    'quern',
    'querulous',
    'querulousness',
    'query',
    'quesadilla',
    'quest',
    'quester',
    'questing',
    'question',
    'questionable',
    'questioned',
    'questioner',
    'questioning',
    'questionnaire',
    'questions',
    'quetch',
    'quetzal',
    'quetzalcoatl',
    'queue',
    'quiaquia',
    'quibble',
    'quibbler',
    'quiche',
    'quick',
    'quicken',
    'quickener',
    'quickening',
    'quickens',
    'quicker',
    'quickest',
    'quickie',
    'quicklime',
    'quickly',
    'quickness',
    'quicksand',
    'quickset',
    'quicksilver',
    'quickstep',
    'quicky',
    'quid',
    'quiddity',
    'quidnunc',
    'quiesce',
    'quiescence',
    'quiescency',
    'quiescent',
    'quiet',
    'quieted',
    'quieten',
    'quietism',
    'quietist',
    'quietly',
    'quietness',
    'quiets',
    'quietude',
    'quietus',
    'quiff',
    'quill',
    'quills',
    'quillwort',
    'quilt',
    'quilted',
    'quilting',
    'quilts',
    'quin',
    'quinacrine',
    'quince',
    'quincentenary',
    'quincentennial',
    'quincy',
    'quine',
    'quinidex',
    'quinidine',
    'quinine',
    'quinone',
    'quinones',
    'quinora',
    'quinquagesima',
    'quinquefoliate',
    'quinquennium',
    'quinsy',
    'quint',
    'quintal',
    'quintessence',
    'quintessential',
    'quintet',
    'quintette',
    'quintillion',
    'quintillionth',
    'quintipara',
    'quintuple',
    'quintuplet',
    'quintupling',
    'quip',
    'quipu',
    'quira',
    'quire',
    'quires',
    'quirk',
    'quirked',
    'quirkiness',
    'quirky',
    'quirt',
    'quiscalus',
    'quisling',
    'quislingism',
    'quit',
    'quitclaim',
    'quite',
    'quito',
    'quits',
    'quittance',
    'quitter',
    'quitting',
    'quiver',
    'quivered',
    'quivering',
    'quixotic',
    'quixotism',
    'quiz',
    'quizmaster',
    'quizzed',
    'quizzer',
    'quizzical',
    'qum',
    'quo',
    'quodlibet',
    'quoin',
    'quoit',
    'quoits',
    'quondam',
    'quoratean',
    'quorum',
    'quota',
    'quotability',
    'quotable',
    'quotas',
    'quotation',
    'quotations',
    'quote',
    'quoted',
    'quoter',
    'quotes',
    'quotidian',
    'quotient',
    'quoting',
    'quran',
    'qurush']
